Crate uv_workspace

Crate uv_workspace 

Modules

dependency_groups
pyproject
Reads the following fields from pyproject.toml:
pyproject_mut

Structs

DiscoveryOptions
ProjectWorkspace
The current project and the workspace it is part of, with all of the workspace members.
Workspace
A workspace, consisting of a root directory and members. See ProjectWorkspace.
WorkspaceCache
Cache for workspace discovery.
WorkspaceError
WorkspaceMember
A project in a workspace.

Enums

MemberDiscovery
ProjectEnvironmentSelection
The workspace project environment selected by configuration and command-line options.
VirtualProject
A project that can be discovered.
WorkspaceErrorKind

Type Aliases

Editability
RequiresPythonSources