VirtualProject

Enum VirtualProject 

pub enum VirtualProject {
    Project(ProjectWorkspace),
    NonProject(Arc<Workspace>),
}
A project that can be discovered.

The project could be a package within a workspace, a real workspace root, or a non-project workspace root, which can define its own dev dependencies.

Variants



Project(ProjectWorkspace)

A project (which could be a workspace root or member).



NonProject(Arc<Workspace>)

A non-project workspace root.

Implementations

Source

impl VirtualProject

pub async fn discover( path: &Path, options: &DiscoveryOptions, cache: &Cache, workspace_cache: &WorkspaceCache, ) -> Result<Self, WorkspaceError>

Find the current project or virtual workspace root, given the current directory.

Similar to calling ProjectWorkspace::discover with a fallback to Workspace::discover, but avoids rereading the pyproject.toml (and relying on error-handling as control flow).

This method requires an absolute path and panics otherwise, i.e. this method only supports discovering the main workspace.

pub async fn discover_with_package( path: &Path, options: &DiscoveryOptions, cache: &Cache, workspace_cache: &WorkspaceCache, package: PackageName, ) -> Result<Self, WorkspaceError>

Discover a project workspace with the member package.

pub fn update_member( self, pyproject_toml: PyProjectToml, workspace_cache: &WorkspaceCache, ) -> Result<Option<Self>, WorkspaceError>

Update the pyproject.toml for the current project.

Assumes that the project name is unchanged in the updated PyProjectToml.

Contract: There are no parallel workspace operations, this is the only thread operating on workspaces.

The WorkspaceCache is passed to ensure the caller doesn’t forget to clear it.

pub fn clone_detach(&self) -> Self

Clone while detaching from the original workspace Arc, freeing the original state for modification.

This is intended for rollbacks only.

pub fn root(&self) -> &Path

Return the root of the project.

pub fn pyproject_toml(&self) -> &PyProjectToml

Return the PyProjectToml of the project.

pub fn workspace(&self) -> &Workspace

Return the Workspace of the project.

pub fn project_name(&self) -> Option<&PackageName>

Return the PackageName of the project, if available.

pub fn is_non_project(&self) -> bool

Returns true if the project is a virtual workspace root.