Modules
- dependency_
groups - pyproject
- Reads the following fields from
pyproject.toml: - pyproject_
mut
Structs
- Discovery
Options - Project
Workspace - The current project and the workspace it is part of, with all of the workspace members.
- Workspace
- A workspace, consisting of a root directory and members. See
ProjectWorkspace. - Workspace
Cache - Cache for workspace discovery.
- Workspace
Error - Workspace
Member - A project in a workspace.
Enums
- Member
Discovery - Project
Environment Selection - The workspace project environment selected by configuration and command-line options.
- Virtual
Project - A project that can be discovered.
- Workspace
Error Kind